''' https://rethinkdb.com/api/python/table_list/ REPL: r.db ('rethinkdb').table_list ().run () PYTHON3: r.db ('rethinkdb').table_list ().run (conn) DATA EXPLORER: r.db ('rethinkdb').tableList () ''' ''' 'cluster_config', r.db ('rethinkdb').table ('cluster_config') 'current_issues', r.db ('rethinkdb').table ('current_issues') 'db_config', r.db ('rethinkdb').table ('db_config') 'jobs', r.db ('rethinkdb').table ('jobs') 'logs', r.db ('rethinkdb').table ('logs') 'permissions', 'server_config', r.db ('rethinkdb').table ('server_config') 'server_status', 'stats', r.db ('rethinkdb').table ('stats') 'table_config', r.db ('rethinkdb').table ('table_config') 'table_status', 'users' r.db ('rethinkdb').table ('users') '''